addedNodes property
Stream<NodeAddEvent<INode> >
get
addedNodes
Listen to this Stream to get updates on when a Node or a collection of Nodes is added to the current node. It returns a stream of NodeAddEvent
Implementation
Stream<NodeAddEvent<INode>> get addedNodes;