removedNodes property

Stream<NodeRemoveEvent<INode>> get removedNodes
override

Listen to this Stream to get updates on when a Node or a collection of Nodes is removed from the current node.

The stream should only be listened to on the root node. ActionNotAllowedException if a non-root tries to listen the removedNodes

Implementation

Stream<NodeRemoveEvent<INode>> get removedNodes {
  if (!isRoot) throw ActionNotAllowedException.listener(this);
  return _removedNodes.stream;
}