ListenableNode constructor
A listenable implementation the Node. The mutations to the Node can be listened to using the ValueListenable interface or the addedNodes and removedNodes streams.
The ListenableNode can also be used with a ValueListenableBuilder for updating the UI whenever the Node is mutated.
Default constructor that takes an optional key and a parent.
Make sure that the provided key is unique to among the siblings of the node.
If a key is not provided, then a UniqueKey will automatically be
assigned to the Node.
Implementation
ListenableNode({String? key, Node? parent}) : super(key: key, parent: parent);