addAll method
Add a collection of Iterable nodes to this node
The ValueListenable and addedNodes listeners will also be notified on this operation
Implementation
void addAll(Iterable<Node> iterable) {
super.addAll(iterable);
_notifyListeners();
_notifyNodesAdded(NodeAddEvent(List.from(iterable)));
}