addedNodes property
Listen to this Stream to get updates on when a Node or a collection of Nodes is added to the current node.
The stream should only be listened to on the root node. ActionNotAllowedException if a non-root tries to listen the addedNodes
Implementation
Stream<NodeAddEvent<INode>> get addedNodes {
if (!isRoot) throw ActionNotAllowedException.listener(this);
return _addedNodes.stream;
}