ExpansionIndicator class
Constructors
- ExpansionIndicator({required Widget expandIcon, required Widget collapseIcon, Alignment alignment = Alignment.topRight, EdgeInsets padding = const EdgeInsets.all(4)})
-
const
Properties
- alignment → Alignment
-
Alignment of the ExpansionIndicator on the ListTile.
By default the alignment is Alignment.topRight
final
- collapseIcon → Widget
-
A collapse indicator to show that the Node is currently in collapsed state.
It is typically an Icon widget.
final
- expandIcon → Widget
-
An expansion indicator to show that the Node is currently in expanded state.
It is typically an Icon widget.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- padding → EdgeInsets
-
The padding around the expandIcon and collapseIcon
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- DownUpChevron → const ExpansionIndicator
- PlusMinus → const ExpansionIndicator
- RightUpChevron → const ExpansionIndicator